summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--Bugzilla/BugMail.pm4
-rw-r--r--extensions/TagNewUsers/Extension.pm2
2 files changed, 3 insertions, 3 deletions
diff --git a/extensions/TagNewUsers/Extension.pm b/extensions/TagNewUsers/Extension.pm
index 4b78c7bc0..ab71eeda8 100644
--- a/extensions/TagNewUsers/Extension.pm
+++ b/extensions/TagNewUsers/Extension.pm
@@ -234,7 +234,7 @@ sub mailer_before_send {
if ($bug_id
&& $changer_login
- && $changed_fields =~ /Attachment Created/)
+ && $changed_fields =~ /attachments.created/)
{
my $changer = Bugzilla::User->new({ name => $changer_login });
if ($changer
diff --git a/Bugzilla/BugMail.pm b/Bugzilla/BugMail.pm
index efbba5215..62f04e5da 100644
--- a/Bugzilla/BugMail.pm
+++ b/Bugzilla/BugMail.pm
@@ -363,10 +363,10 @@ sub sendMail {
my @changedfields = uniq map { $_->{field_name} } @display_diffs;
# Add Attachment Created to changedfields if one or more
# comments contain information about a new attachment
if (grep($_->type == CMT_ATTACHMENT_CREATED, @send_comments)) {
- push(@changedfields, 'Attachment Created');
+ push(@changedfields, 'attachments.created');
}
my $vars = {
@@ -363,10 +363,10 @@ sub sendMail {
my @changedfields = uniq map { $_->{field_name} } @display_diffs;
- # Add Attachment Created to changedfields if one or more
+ # Add attachments.created to changedfields if one or more
# comments contain information about a new attachment
if (grep($_->type == CMT_ATTACHMENT_CREATED, @send_comments)) {